{#
  Copyright (C) 2024 CERN.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_theme/page_cover.html" %}

{% block site_banner %}
  {% from 'invenio_banners/banner.html' import banner %}
  {{ banner() }}
{% endblock site_banner %}
